@@ -51,7 +51,8 @@ autoplot.sscurves <- function(object, curvetype = c("ROC", "PRC"), ...) {
                                    def_show_cb = FALSE, def_raw_curves = TRUE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = FALSE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = TRUE, ...)
   arglist[["raw_curves"]] <- TRUE
   arglist[["show_cb"]] <- FALSE
   arglist[["curvetype"]] <- .pmatch_curvetype_rocprc(arglist[["curvetype"]])
@@ -68,7 +69,8 @@ autoplot.mscurves <- function(object, curvetype = c("ROC", "PRC"), ...) {
                                    def_show_cb = FALSE, def_raw_curves = TRUE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = TRUE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = TRUE, ...)
   arglist[["raw_curves"]] <- TRUE
   arglist[["show_cb"]] <- FALSE
   arglist[["curvetype"]] <- .pmatch_curvetype_rocprc(arglist[["curvetype"]])
@@ -84,7 +86,8 @@ autoplot.smcurves <- function(object, curvetype = c("ROC", "PRC"), ...) {
                                    def_show_cb = TRUE, def_raw_curves = FALSE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = FALSE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = TRUE, ...)
 
   arglist[["curvetype"]] <- .pmatch_curvetype_rocprc(arglist[["curvetype"]])
 
@@ -99,7 +102,8 @@ autoplot.mmcurves <- function(object, curvetype = c("ROC", "PRC"), ...) {
                                    def_show_cb = FALSE, def_raw_curves = FALSE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = TRUE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = TRUE, ...)
 
   arglist[["curvetype"]] <- .pmatch_curvetype_rocprc(arglist[["curvetype"]])
 
@@ -119,7 +123,8 @@ autoplot.sspoints <- function(object,
                                    def_show_cb = FALSE, def_raw_curves = TRUE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = FALSE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = FALSE, ...)
   arglist[["raw_curves"]] <- TRUE
   arglist[["show_cb"]] <- FALSE
   arglist[["curvetype"]] <- .pmatch_curvetype_basic(arglist[["curvetype"]])
@@ -141,7 +146,8 @@ autoplot.mspoints <- function(object,
                                    def_show_cb = FALSE, def_raw_curves = TRUE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = TRUE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = FALSE, ...)
   arglist[["raw_curves"]] <- TRUE
   arglist[["show_cb"]] <- FALSE
   arglist[["curvetype"]] <- .pmatch_curvetype_basic(arglist[["curvetype"]])
@@ -162,7 +168,8 @@ autoplot.smpoints <- function(object,
                                    def_show_cb = TRUE, def_raw_curves = FALSE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = FALSE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = FALSE, ...)
 
   arglist[["curvetype"]] <- .pmatch_curvetype_basic(arglist[["curvetype"]])
 
@@ -182,7 +189,8 @@ autoplot.mmpoints <- function(object,
                                    def_show_cb = FALSE, def_raw_curves = FALSE,
                                    def_add_np_nn = TRUE,
                                    def_show_legend = TRUE,
-                                   def_ret_grob = FALSE, ...)
+                                   def_ret_grob = FALSE,
+                                   def_reduce_points = FALSE, ...)
 
   arglist[["curvetype"]] <- .pmatch_curvetype_basic(arglist[["curvetype"]])
 
